package
Version:
v0.0.0-...-fb9da95
Opens a new window with list of versions in this module.
Published: Aug 2, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Source interface {
IntN(n int) int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.